@@ -1,7 +1,7 @@
-from . import BaseAgent
+from . import NetworkAgent
 
 
-class CounterModel(BaseAgent):
+class CounterModel(NetworkAgent):
     """
     Dummy behaviour. It counts the number of nodes in the network and neighbors
     in each step and adds it to its state.
@@ -9,24 +9,30 @@ class CounterModel(BaseAgent):
 
     def step(self):
         # Outside effects
-        total = len(list(self.get_all_agents()))
+        total = len(list(self.get_agents()))
         neighbors = len(list(self.get_neighboring_agents()))
         self['times'] = self.get('times', 0) + 1
         self['neighbors'] = neighbors
         self['total'] = total
 
 
-class AggregatedCounter(BaseAgent):
+class AggregatedCounter(NetworkAgent):
     """
     Dummy behaviour. It counts the number of nodes in the network and neighbors
     in each step and adds it to its state.
     """
 
+    defaults = {
+        'times': 0,
+        'neighbors': 0,
+        'total': 0
+    }
+
     def step(self):
         # Outside effects
-        total = len(list(self.get_all_agents()))
+        self['times'] += 1
         neighbors = len(list(self.get_neighboring_agents()))
-        self['times'] = self.get('times', 0) + 1
-        self['neighbors'] = self.get('neighbors', 0) + neighbors
-        self['total'] = total = self.get('total', 0) + total
+        self['neighbors'] += neighbors
+        total = len(list(self.get_agents()))
+        self['total'] += total
         self.debug('Running for step: {}. Total: {}'.format(self.now, total))
